@@ -1,7 +1,6 @@
-# Maintained now in B::C by Reini Urban <rurban@x-ray.at>
 package B::Bblock;
 
-our $VERSION = '1.03_02';
+our $VERSION = '1.03';
 
 use Exporter ();
 @ISA       = "Exporter";
@@ -127,14 +126,10 @@ sub B::LISTOP::mark_if_leader {
 
 sub B::PMOP::mark_if_leader {
   my $op = shift;
-  if (  $op->type
-    and $op->name ne "pushre"
-    and ($] > 5.008005 or $op->name ne "substcont") )
-  {
-    #warn $op->name, $op->type if $] == 5.008004;
+  if ( $op->name ne "pushre" ) {
     my $replroot = $op->pmreplroot;
     if ($$replroot) {
-      mark_leader( $replroot );
+      mark_leader($replroot);
       mark_leader( $op->next );
       mark_leader( $op->pmreplstart );
     }
@@ -151,7 +146,6 @@ sub compile {
       my $objname;
       foreach $objname (@options) {
         $objname = "main::$objname" unless $objname =~ /::/;
-        print "walk_bblocks $objname\n";
         eval "walk_bblocks_obj(\\&$objname)";
         die "walk_bblocks_obj(\\&$objname) failed: $@" if $@;
         print "-------\n";
@@ -173,6 +167,17 @@ sub compile {
   }
 }
 
+# Basic block leaders:
+#     Any COP (pp_nextstate) with a non-NULL label
+#     [The op after a pp_enter] Omit
+#     [The op after a pp_entersub. Don't count this one.]
+#     The ops pointed at by nextop, redoop and lastop->op_next of a LOOP
+#     The ops pointed at by op_next and op_other of a LOGOP, except
+#     for pp_entertry which has op_next and op_other->op_next
+#     The op pointed at by op_pmreplstart of a PMOP
+#     The op pointed at by op_other->op_pmreplstart of pp_substcont?
+#     [The op after a pp_return] Omit
+
 1;
 
 __END__
@@ -186,43 +191,20 @@ B::Bblock - Walk basic blocks
   # External interface
   perl -MO=Bblock[,OPTIONS] foo.pl
 
-    perl -MO=Bblock foo.pl     prints the basic block for main_root
-    perl -MO=Bblock,foo::mysub foo.pm prints the basic block for &pkg::mysub
-    perl -MO=Bblock,mysub foo.pm prints the basic block for &main::mysub
-
   # Programmatic API
   use B::Bblock qw(find_leaders);
   my $leaders = find_leaders($root_op, $start_op);
 
 =head1 DESCRIPTION
 
-This module is used by the L<B::CC> backend.  It walks "basic blocks".
+This module is used by the B::CC back end.  It walks "basic blocks".
 A basic block is a series of operations which is known to execute from
 start to finish, with no possibility of branching or halting.
 
-The block is the list of ops from the every leader up to the next.
-The leaders are the separator of each basic block.
+It can be used either stand alone or from inside another program.
 
-The module can be used either stand alone or from inside another program.
-Standalone it just prints the basic blocks ops in L<B::Concise>.
-terse format to STDOUT.
-Without options it starts at the main_root.
-
-Basic block leaders are:
-
-     Any COP (pp_nextstate) with a non-NULL label.
-       [The op after a pp_enter] Omit
-       [The op after a pp_entersub. Don't count this one.]
-     The ops pointed at by nextop, redoop and lastop->op_next of a LOOP.
-     The ops pointed at by op_next and op_other of a LOGOP, except
-       for pp_entertry which has op_next and op_other->op_next
-     The op pointed at by op_pmreplstart of a PMOP.
-     The op pointed at by op_other->op_pmreplstart of pp_substcont?
-       [The op after a pp_return] Omit
-
-=head1 OPTIONS
-
-A comma-separated list of sub names to walk.
+=for _private
+Somebody who understands the stand-alone options document them, please.
 
 =head2 Functions
 
@@ -236,21 +218,21 @@ Given the root of the op tree and an op from which to start
 processing, it will return a hash ref representing all the ops which
 start a block.
 
+=for _private
+The above description may be somewhat wrong.
+
 The values of %$leaders are the op objects themselves.  Keys are $$op
 addresses.
 
+=for _private
+Above cribbed from B::CC's comments.  What's a $$op address?
+A: See http://books.simon-cozens.org/index.php/Perl_5_Internals#Using_B_for_Simple_Things
+
 =back
 
+
 =head1 AUTHOR
 
-Malcolm Beattie C<MICB at cpan.org> I<(retired)>,
-Reini Urban C<perl-compiler@googlegroups.com>
+Malcolm Beattie, C<mbeattie@sable.ox.ac.uk>
 
 =cut
-
-# Local Variables:
-#   mode: cperl
-#   cperl-indent-level: 2
-#   fill-column: 78
-# End:
-# vim: expandtab shiftwidth=2:
