@@ -1,17 +1,19 @@
 #!/bin/bash
 # t/testc.sh -c -Du,-q -B static 2>&1 |tee c.log|grep FAIL
-# for p in 5.6.2 5.8.6 5.8.9d 5.10.1d 5.10.1d-nt 5.11.2d 5.11.2d-nt; do make -s clean; perl$p Makefile.PL; t/testc.sh -O0 16; done
+# for p in 5.6.2 5.8.8-nt 5.8.9d 5.10.1d 5.10.1d-nt 5.11.2d 5.11.2d-nt; do make -s clean; perl$p Makefile.PL; t/testc.sh -O0 16; done
 # quiet c only: t/testc.sh -q -O0
 function help {
-  echo "t/testc.sh [OPTIONS] [1-26]"
+  echo "t/testc.sh [OPTIONS] [1-29]"
   echo " -D debugflags      for O=C or O=CC. Default: C,-DcOACMSGpu,-v resp. CC,-DoOscprSql,-v"
   echo " -O 0|1|2|3         optimization level"
   echo " -B static|dynamic  pass to cc_harness"
   echo " -c                 continue on errors"
+  echo " -k                 keep temp. files on PASS"
+  echo " -E                 dump preprocessed source file with cc -E as _E.c"
   echo " -a                 all. undo -Du. Unsilence scanning unused sub"
   echo " -q                 quiet"
   echo " -h                 help"
-  echo "Without arguments try all 26 tests. Without Option -Ox try all three optimizations."
+  echo "Without arguments try all 29 tests. Without Option -Ox try all three optimizations."
 }
 
 # use the actual perl from the Makefile (perl5.8.8, 
@@ -72,7 +74,7 @@ function runopt {
          fi
     fi
     vcmd ${CMD}-o${o}${suff}.c $o.pl
-    vcmd $CCMD ${o}${suff}.c -c -E -o ${o}${suff}_E.c
+    test -n $CPP && vcmd $CCMD ${o}${suff}.c -c -E -o ${o}${suff}_E.c
     vcmd $CCMD ${o}${suff}.c $LCMD -o ${o}${suff}
     test -x ${o}${suff} || (test -z $CONT && exit)
     if [ -z "$QUIET" ]; then echo "./${o}${suff}"
@@ -81,6 +83,7 @@ function runopt {
     res=$(./${o}${suff}) || fail "./${o}${suff}" "errcode $?"
     if [ "X$res" = "X${result[$n]}" ]; then
 	test "X$res" = "X${result[$n]}" && pass "./${o}${suff}" "=> '$res'"
+        if [ -z $KEEP ]; then rm ${o}${suff}_E.c ${o}${suff}.c ${o}.pl ${o}${suff}; fi
     else
 	fail "./${o}${suff}" "=> '$str' => '$res'. Expected: '${result[$n]}'"
     fi
@@ -108,7 +111,7 @@ function ctest {
 	rm $o.c $o ${o}_o.c ${o}_o 2> /dev/null
 	vcmd ${OCMD}-o$o.c $o.pl
         test -s $o.c || (echo "empty $o.c"; test -z $CONT && exit)
-	vcmd $CCMD $o.c -c -E -o ${o}_E.c
+	test -n $CPP && vcmd $CCMD $o.c -c -E -o ${o}_E.c
 	vcmd $CCMD $o.c $LCMD -o $o
 	test -x $o || (test -z $CONT && exit)
 	if [ -z "$QUIET" ]; then echo "./$o"
@@ -117,6 +120,7 @@ function ctest {
 	res=$(./$o) || (fail "./${o}${suff}" "'$?' = $?"; test -z $CONT && exit)
 	if [ "X$res" = "X${result[$n]}" ]; then
 	    pass "./$o" "'$str' => '$res'"
+            if [ -z $KEEP ]; then rm ${o}_E.c ${o}.c ${o}.pl ${o}; fi
 	    runopt $o 1
 	    runopt $o 2
 	    #runopt $o 3
@@ -128,7 +132,7 @@ function ctest {
     fi
 }
 
-ntests=26
+ntests=29
 declare -a tests[$ntests]
 declare -a result[$ntests]
 tests[1]="print 'hi'"
@@ -201,10 +205,19 @@ result[25]="0 1 2 3`$PERL -e'print (($] < 5.007) ? q( 4 5) : q())'` 4321";
 # lvalue
 tests[26]='sub a:lvalue{my $a=26; ${\(bless \$a)}}sub b:lvalue{${\shift}}; print ${a(b)}';
 result[26]="26";
+# import test
+tests[27]='use Fcntl; print "ok" if ( &Fcntl::O_WRONLY );'
+result[27]='ok'
+# require $fname
+tests[28]='my $tmpdir=$ENV{TMPDIR}||"/tmp";my($fname,$tmp_fh);while(!open($tmp_fh,">",($fname= $tmpdir . q{/perlcctest_27.} . rand(999999999999)))){$bail++;die "Failed to create a tmp file after 500 tries" if ($bail>500);}print {$tmp_fh} q{$x="ok";1;};close($tmp_fh);require $fname;unlink($fname);print $x;'
+result[28]='ok'
+# use test
+tests[29]='use IO;print "ok"'
+result[29]='ok'
 
 # 
-# getopts for -q -Du,-q -v -O2, -a -c
-while getopts "hqacD:B:O:" opt
+# getopts for -q -k -E -Du,-q -v -O2, -a -c
+while getopts "hqackED:B:O:" opt
 do
   if [ "$opt" = "q" ]; then 
     QUIET=1
@@ -217,7 +230,9 @@ do
     OCMDO3="$(echo $OCMDO3|sed -e 's/-D.*,-v,//' -e s/-MO=/-MO=$qq/)"
     CCMD="$PERL script/cc_harness -q -g3 -Bdynamic"
   fi
-  if [ "$opt" = "c" ]; then CONT=1; shift; fi
+  if [ "$opt" = "c" ]; then CONT=1; fi
+  if [ "$opt" = "k" ]; then KEEP=1; fi
+  if [ "$opt" = "E" ]; then CPP=1; fi
   if [ "$opt" = "h" ]; then help; exit; fi
   # -D options: u,-q for quiet, no -D for verbose
   if [ "$opt" = "D" ]; then
@@ -257,12 +272,12 @@ else
   done
 fi
 
-# 562  c:  15,24
-# 58   c:  15
-# 58  cc:  10_o,15,16_o,18-19,21,24
-# 510  c:  7,11,14-15,20-21,23
-# 510 cc:  +10_o,12,16_o,18,19
-# 511  c:  11,14-16,23
+# 562  c:  15,25,27
+# 58   c:  27,29_i
+# 58  cc:  15,18,21,25,26_o,27,29
+# 510  c:  15
+# 510 cc:  11,15,29
+# 511  c:  11,15,16,29
 
 #  http://www.nntp.perl.org/group/perl.perl5.porters/2005/07/msg103315.html
 #  FAIL for B::CC should be covered by test 18
